Dragonite
============

Dragonite is a command-line utility which gathers room availability
information from the host hotels of the annual
`Dragon Con <http://www.dragoncon.org/>`_ event.


Installation
--------------

.. code:: bash

    pip install dragonite


Usage
--------

.. code:: bash

    dragonite --help
